package
Version:
v0.0.0-...-10dc113
Opens a new window with list of versions in this module.
Published: Oct 29, 2017
License: MIT, Apache-2.0
Opens a new window with license information.
Imports: 7
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
fempla
Package fempla is a middleware that provides femplate(fasttemplate) template engine support for vodka.
Installation
go get -u github.com/vodka-contrib/fempla
Document
Gowalker or Godoc
Example
please check example
Documentation
¶
type Renderer struct {
Option
}
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.